@@ -36,10 +36,11 @@
 #endif
 
 #include "fs-rtp-stream.h"
-#include "fs-rtp-marshal.h"
 
 #include <gst/gst.h>
 
+#include "fs-rtp-marshal.h"
+
 /* Signals */
 enum
 {
@@ -630,6 +631,7 @@ fs_rtp_stream_set_remote_codecs (FsStream *stream,
   GList *item = NULL;
   FsMediaType media_type;
   FsRtpSession *session = fs_rtp_stream_get_session (self, error);
+  GList *remote_codecs_copy;
 
   if (!session)
     return FALSE;
@@ -668,7 +670,8 @@ fs_rtp_stream_set_remote_codecs (FsStream *stream,
     }
   }
 
-  if (self->priv->new_remote_codecs_cb (self, remote_codecs, error,
+  remote_codecs_copy = codecs_copy_with_new_ptime (remote_codecs);
+  if (self->priv->new_remote_codecs_cb (self, remote_codecs_copy, error,
           self->priv->user_data_for_cb))
   {
     gboolean is_new = TRUE;
@@ -679,12 +682,13 @@ fs_rtp_stream_set_remote_codecs (FsStream *stream,
       is_new = !fs_codec_list_are_equal (self->remote_codecs, remote_codecs);
       fs_codec_list_destroy (self->remote_codecs);
     }
-    self->remote_codecs = fs_codec_list_copy (remote_codecs);
+    self->remote_codecs = remote_codecs_copy;
     FS_RTP_SESSION_UNLOCK (session);
 
     if (is_new)
       g_object_notify (G_OBJECT (stream), "remote-codecs");
   } else {
+    fs_codec_list_destroy (remote_codecs_copy);
     goto error;
   }
 
